@@ -3,13 +3,10 @@ from .action_value_mixin import ActionValueFunction
 from .action_value_mixin import ActionValueMixin
 from .deterministic_actor_mixin import DeterministicActorMixin
 from .deterministic_actor_mixin import DeterministicPolicy
-from .normalizing_flow_actor_mixin import NormalizingFlowActorMixin
-from .normalizing_flow_model_mixin import NormalizingFlowModelMixin
 from .state_value_mixin import StateValueMixin
 from .stochastic_actor_mixin import MaximumEntropyMixin
 from .stochastic_actor_mixin import StochasticActorMixin
 from .stochastic_actor_mixin import StochasticPolicy
-from .stochastic_model_mixin import StochasticModel
 from .stochastic_model_mixin import StochasticModelMixin
 from .svg_model_mixin import SVGModelMixin
 
@@ -18,13 +15,10 @@ __all__ = [
     "ActionValueFunction",
     "DeterministicActorMixin",
     "DeterministicPolicy",
-    "NormalizingFlowActorMixin",
-    "NormalizingFlowModelMixin",
     "StateValueMixin",
     "StochasticActorMixin",
     "MaximumEntropyMixin",
     "StochasticPolicy",
     "StochasticModelMixin",
-    "StochasticModel",
     "SVGModelMixin",
 ]
